import { GltfData } from "./GltfData";
/**
 * Utility methods related to glTF accessors.
 *
 * NOTE: These methods are only intended for the use in the
 * glTF extension validation. They make assumptions about
 * the validity of the glTF asset (as established by the
 * glTF Validator), and the structure of the glTF asset
 * (as established by the extension validator).
 *
 * @internal
 */
export declare class Accessors {
    /**
     * Read the values of the given accessor into an array of numbers.
     *
     * This assumes that the accessor has the type SCALAR, and is
     * valid (in terms of its bufferView etc), as validated with
     * the glTF Validator.
     *
     * @param accessorIndex - The glTF accessor index
     * @param gltfData - The glTF data
     * @returns The accessor values (or undefined if the input
     * glTF data was invalid)
     */
    static readScalarAccessorValues(accessorIndex: number, gltfData: GltfData): number[] | undefined;
    /**
     * Read the values of the given accessor into an array of
     * arrays of numbers.
     *
     * This assumes that the accessor has the type VECn or MATn, and
     * is valid (in terms of its bufferView etc), as validated with
     * the glTF Validator.
     *
     * @param accessorIndex - The glTF accessor index
     * @param gltfData - The glTF data
     * @returns The accessor values (or undefined if the input
     * glTF data was invalid)
     */
    static readArrayAccessorValues(accessorIndex: number, gltfData: GltfData): number[][] | undefined;
}
//# sourceMappingURL=Accessors.d.ts.map