import { ValidationContext } from "../ValidationContext";
import { GltfData } from "./GltfData";
/**
 * A class for validating the `EXT_structural_metadata` extension in
 * glTF assets.
 *
 * This class assumes that the structure of the glTF asset itself
 * has already been validated (e.g. with the glTF Validator).
 *
 * @internal
 */
export declare class ExtStructuralMetadataValidator {
    /**
     * Performs the validation to ensure that the `EXT_structural_metadata`
     * extensions in the given glTF are valid
     *
     * @param path - The path for validation issues
     * @param gltfData - The glTF data, containing the parsed JSON and the
     * (optional) binary buffer
     * @param context - The `ValidationContext` that any issues will be added to
     * @returns Whether the object was valid
     */
    static validateGltf(path: string, gltfData: GltfData, context: ValidationContext): Promise<boolean>;
    /**
     * Validate the given top-level EXT_structural_metadata extension object
     * that was found in the given glTF.
     *
     * @param path - The path for validation issues
     * @param structuralMetadata - The EXT_structural_metadata extension object
     * @param schemaState - The object holding information about the presence
     * and validity of the schema
     * @param gltfData - The glTF data
     * @param context - The `ValidationContext` that any issues will be added to
     * @returns Whether the object was valid
     */
    private static validateTopLevelStructuralMetadata;
    /**
     * Validate the given EXT_structural_metadata extension object
     * that was found in the given mesh primitive.
     *
     * @param path - The path for validation issues
     * @param meshPrimitiveStructuralMetadata - The EXT_mesh_features
     * extension object that was found in the mesh primitive
     * @param meshPrimitive - The mesh primitive that contained
     * the extension object
     * @param meshIndex - The index of the mesh (only for details
     * in validation messages)
     * @param pimitiveIndex - The index of the primitive (only for details
     * in validation messages)
     * @param schema - The metadata schema
     * @param gltfStructuralMetadata - The EXT_mesh_features object
     * that was found at the top level in the glTF asset
     * @param gltfData - The glTF data
     * @param context - The `ValidationContext` that any issues will be added to
     * @returns Whether the object was valid
     */
    private static validateMeshPrimitiveStructuralMetadata;
}
//# sourceMappingURL=ExtStructuralMetadataValidator.d.ts.map