import { ValidationContext } from "../ValidationContext";
import { ValidatedElement } from "../ValidatedElement";
import { GltfData } from "./GltfData";
/**
 * Methods related to the validation of accessors that store
 * feature IDs, in the context of the `EXT_mesh_features` and
 * `EXT_instance_features` extensions.
 */
export declare class FeatureIdAccessorValidator {
    /**
     * Validate the given feature ID attribute accessor index that
     * was found in the mesh primitive attributes for the
     * `_FEATURE_ID_${attribute}` attribute.
     *
     * @param path - The path for validation issues
     * @param accessorIndex - The accessor index
     * @param featureCount - The `featureCount` value from the feature ID definition
     * @param gltfData - The glTF data
     * @param propertyTableState - The validation state of the property table
     * definition (i.e. the index into the property tables array)
     * @param nullFeatureId - The `nullFeatureId` of the `featureId` object
     * @param context - The `ValidationContext` that any issues will be added to
     * @returns Whether the object was valid
     */
    static validateFeatureIdAccessor(path: string, accessorIndex: number, featureCount: number, gltfData: GltfData, propertyTableState: ValidatedElement<{
        count: number;
    }>, nullFeatureId: number | undefined, context: ValidationContext): boolean;
    /**
     * Validate the data of the given feature ID atribute.
     *
     * This assumes that the glTF data is valid as determined by the
     * glTF Validator, **AND** as determined by the validation of
     * the JSON part of the extension. So this method should only
     * be called when no issues have been detected that may prevent
     * the validation of the accessor values. If this is called
     * with a `gltfData` object where the `gltfDocument` is
     * `undefined`, then an `INTERNAL_ERROR` will be caused.
     *
     * @param path - The path for validation issues
     * @param accessorIndex - The feature ID attribute accessor index
     * @param featureCount - The `featureCount` value from the feature ID definition
     * @param gltfData - The glTF data
     * @param propertyTableState - The validation state of the property table
     * definition (i.e. the index into the property tables array)
     * @param nullFeatureId - The `nullFeatureId` of the `featureId` object
     * @param context - The `ValidationContext` that any issues will be added to
     * @returns Whether the object was valid
     */
    private static validateFeatureIdAcessorData;
}
//# sourceMappingURL=FeatureIdAccessorValidator.d.ts.map