"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GltfExtensionValidators = void 0;
const ExtInstanceFeaturesValidator_1 = require("./ExtInstanceFeaturesValidator");
const ExtMeshFeaturesValidator_1 = require("./ExtMeshFeaturesValidator");
const ExtStructuralMetadataValidator_1 = require("./ExtStructuralMetadataValidator");
const GltfDataReader_1 = require("./GltfDataReader");
/**
 * A class that only serves as an entry point for validating
 * glTF extensions, given the raw glTF input data (either
 * as embedded glTF, or as binary glTF).
 */
class GltfExtensionValidators {
    /**
     * Ensure that the extensions in the given glTF data are valid.
     *
     * @param path - The path for `ValidationIssue` instances
     * @param input - The raw glTF data
     * @param context - The `ValidationContext`
     * @returns Whether the object is valid
     */
    static async validateGltfExtensions(path, input, context) {
        const gltfData = await GltfDataReader_1.GltfDataReader.readGltfData(path, input, context);
        if (!gltfData) {
            // Issue was already added to context
            return false;
        }
        let result = true;
        // Validate `EXT_mesh_features`
        const extMeshFeaturesValid = await ExtMeshFeaturesValidator_1.ExtMeshFeaturesValidator.validateGltf(path, gltfData, context);
        if (!extMeshFeaturesValid) {
            result = false;
        }
        // Validate `EXT_instance_features`
        const extInstanceFeatures = await ExtInstanceFeaturesValidator_1.ExtInstanceFeaturesValidator.validateGltf(path, gltfData, context);
        if (!extInstanceFeatures) {
            result = false;
        }
        // Validate `EXT_structural_metadata`
        const extStructuralMetadataValid = await ExtStructuralMetadataValidator_1.ExtStructuralMetadataValidator.validateGltf(path, gltfData, context);
        if (!extStructuralMetadataValid) {
            result = false;
        }
        return result;
    }
}
exports.GltfExtensionValidators = GltfExtensionValidators;
