"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PropertyAttributePropertyModel = void 0;
const _3d_tiles_tools_1 = require("3d-tiles-tools");
/**
 * Implementation of a metadata property model for a
 * property attribute property, backed by glTF accessor
 * data.
 */
class PropertyAttributePropertyModel {
    /**
     * Creates a new instance
     *
     * @param accessorData - The accessor data
     * @param propertyAttributeProperty - The property attribute property
     * @param classProperty - The class property
     */
    constructor(accessorData, propertyAttributeProperty, classProperty) {
        this.accessorData = accessorData;
        this.propertyAttributeProperty = propertyAttributeProperty;
        this.classProperty = classProperty;
    }
    /** {@inheritDoc MetadataPropertyModel.getPropertyValue} */
    getPropertyValue(index) {
        const propertyAttributeProperty = this.propertyAttributeProperty;
        const classProperty = this.classProperty;
        const offsetOverride = propertyAttributeProperty.offset;
        const scaleOverride = propertyAttributeProperty.scale;
        const value = this.getRawPropertyValue(index);
        const processedValue = _3d_tiles_tools_1.MetadataValues.processValue(classProperty, offsetOverride, scaleOverride, value);
        return processedValue;
    }
    /** {@inheritDoc MetadataPropertyModel.getRawPropertyValue} */
    getRawPropertyValue(index) {
        const accessorData = this.accessorData;
        return accessorData[index];
    }
}
exports.PropertyAttributePropertyModel = PropertyAttributePropertyModel;
