import { ClassProperty } from "3d-tiles-tools";
import { ValidationContext } from "../ValidationContext";
/**
 * A class for validations related to `propertyAttribute.property` objects.
 *
 * @internal
 */
export declare class PropertyAttributePropertyValidator {
    /**
     * Performs the validation to ensure that the given object is a
     * valid `propertyAttribute.property` object.
     *
     * @param path - The path for the `ValidationIssue` instances
     * @param propertyName - The name of the property
     * @param propertyAttributeProperty - The object to validate
     * @param classProperty - The `ClassProperty` definition from the schema
     * @param enumValueType - The `valueType` of the enum, if the class
     * property is an ENUM type
     * @param context - The `ValidationContext` that any issues will be added to
     * @returns Whether the object was valid
     */
    static validatePropertyAttributeProperty(path: string, propertyName: string, propertyAttributeProperty: any, classProperty: ClassProperty, enumValueType: string | undefined, context: ValidationContext): boolean;
    /**
     * Validates that the given `classProperty` is basically suitable
     * for a property attribute, meaning that its type is one of the
     * types that can be represented with a glTF vertex attribute.
     *
     * If the type is not valid, then a validation error will be added
     * to the given context, and `false` will be returned.
     *
     * @param path - The path for the `ValidationIssue` instances
     * @param propertyName - The name of the property
     * @param classProperty - The `ClassProperty` definition from the schema
     * @param enumValueType - The `valueType` of the enum, if the class
     * property is an ENUM type
     * @param context - The `ValidationContext` that any issues will be added to
     * @returns Whether the object was valid
     */
    static validateClassPropertyForPropertyAttributeProperty(path: string, propertyName: string, classProperty: ClassProperty, enumValueType: string | undefined, context: ValidationContext): boolean;
}
//# sourceMappingURL=PropertyAttributePropertyValidator.d.ts.map