import { Schema } from "3d-tiles-tools";
import { ValidationContext } from "../ValidationContext";
/**
 * A class for validations related to `propertyAttribute` objects.
 *
 * This class performs the basic JSON-level validation of the
 * property attributes.
 *
 * The validation of any of the underlying binary data of
 * a property attribute has to start at the mesh primitive
 * that refers to the property attribute, because it requires
 * knowledge about the attributes that are defined in the
 * referring mesh primitive.
 *
 * @internal
 */
export declare class PropertyAttributeValidator {
    /**
     * Performs the validation to ensure that the given object is a
     * valid `propertyAttribute` object.
     *
     * @param path - The path for the `ValidationIssue` instances
     * @param propertyAttribute - The object to validate
     * @param schema - The `Schema` object
     * @param context - The `ValidationContext` that any issues will be added to
     * @returns Whether the object was valid
     */
    static validatePropertyAttribute(path: string, propertyAttribute: any, schema: Schema, context: ValidationContext): boolean;
}
//# sourceMappingURL=PropertyAttributeValidator.d.ts.map