import { Schema } from "3d-tiles-tools";
import { ValidationContext } from "../ValidationContext";
import { ValidatedElement } from "../ValidatedElement";
/**
 * A class for validating the definition of property attributes.
 */
export declare class PropertyAttributesDefinitionValidator {
    /**
     * Validate the given definition of property attributes.
     *
     * The returned object will contain two properties:
     * - `wasPresent`: Whether property attributes have been given
     * - `validatedElement`: The validated `PropertyAttribute[]` object
     *
     * When no property attributes are given, then it will just return
     * `{false, undefined}`.
     *
     * If the given `schemaState` indicates that no schema was present,
     * or the property attributes have not been valid according to the
     * schema, then an error will be added to the given context,
     * and `{true, undefined}` is returned.
     *
     * The method will return `{true, propertyattributes}` only if the
     * given property attributes have been valid.
     *
     * @param path - The path for `ValidationIssue` instances
     * @param name - The name of the object containing the definition
     * (for example, 'metadata extension object')
     * @param propertyattributes - The actual property attributes
     * @param gltf - The containing glTF object
     * @param schemaState - The state of the schema validation
     * @param context - The `ValidationContext`
     * @returns Information about the validity of the definition
     */
    static validatePropertyAttributesDefinition(path: string, name: string, propertyAttributes: any[] | undefined, schemaState: ValidatedElement<Schema>, context: ValidationContext): ValidatedElement<any[]>;
}
//# sourceMappingURL=PropertyAttributesDefinitionValidator.d.ts.map