import { ValidatedElement } from "../ValidatedElement";
import { ValidationContext } from "../ValidationContext";
import { GltfData } from "./GltfData";
/**
 * A class for the validation of a single property table that
 * is referred to by a feature ID definition.
 *
 */
export declare class PropertyTableDefinitionValidator {
    /**
     * Validate the given feature ID `propertyTable` value that was found in
     * a feature ID definition.
     *
     * The returned object will contain two properties:
     * - `wasPresent`: Whether a propertyTable (index) was given
     * - `validatedElement`: The validated property table object, only
     *    insofar that it contains a defined `count` value
     *
     * This will check whether the `propertyTable` refers to an exising
     * property table in the `EXT_structural_metadata` extension object,
     * and this property table has a valid `count`.
     *
     * It will NOT check the validity of the property table itself. This
     * will be done by the `EXT_structural_metadata` validator.
     *
     * @param path - The path for validation issues
     * @param propertyTableIndex - The value that was found as the `propertyTable`
     * in the definition, indicating the index into the property tables array
     * @param gltfData - The glTF data
     * @param context - The `ValidationContext` that any issues will be added to
     * @returns Whether the state summarizing the definition
     */
    static validatePropertyTableDefinition(path: string, propertyTableIndex: number | undefined, gltfData: GltfData, context: ValidationContext): ValidatedElement<{
        count: number;
    }>;
}
//# sourceMappingURL=PropertyTableDefinitionValidator.d.ts.map