import { ClassProperty } from "3d-tiles-tools";
import { ImageData } from "./ImageData";
import { MetadataPropertyModel } from "../metadata/MetadataPropertyModel";
/**
 * Implementation of a MetadataPropertyModel for a single
 * property texture property that contains boolean values.
 *
 * @internal
 */
export declare class PropertyTextureBooleanMetadataPropertyModel implements MetadataPropertyModel<[number, number]> {
    /**
     * The image data that was read from the glTF texture
     */
    private readonly imageData;
    /**
     * The property texture property that is represented by this model
     */
    private readonly propertyTextureProperty;
    /**
     * The class property that defines the structure of the property
     */
    private readonly classProperty;
    /**
     * Creates a new instance
     *
     * @param imageData - The image data
     * @param propertyTextureProperty - The property texture property
     * @param classProperty - The class property
     */
    constructor(imageData: ImageData, propertyTextureProperty: any, classProperty: ClassProperty);
    /** {@inheritDoc MetadataPropertyModel.getPropertyValue} */
    getPropertyValue(pixelCoordinates: [number, number]): boolean | boolean[];
    /** {@inheritDoc MetadataPropertyModel.getRawPropertyValue} */
    getRawPropertyValue(pixelCoordinates: [number, number]): boolean | boolean[];
}
//# sourceMappingURL=PropertyTextureBooleanMetadataPropertyModel.d.ts.map