import { ClassProperty } from "3d-tiles-tools";
import { ImageData } from "./ImageData";
import { MetadataPropertyModel } from "../metadata/MetadataPropertyModel";
/**
 * Implementation of a MetadataPropertyModel for a single
 * property texture property that contains enum values.
 *
 * @internal
 */
export declare class PropertyTextureEnumMetadataPropertyModel implements MetadataPropertyModel<[number, number]> {
    /**
     * The image data that was read from the glTF texture
     */
    private readonly imageData;
    /**
     * The property texture property that is represented by this model
     */
    private readonly propertyTextureProperty;
    /**
     * The class property that defines the structure of the property
     */
    private readonly classProperty;
    /**
     * The value type of the enum that is represented with the
     * given class property
     */
    private readonly enumValueType;
    /**
     * The mapping from enum value values to enum value names for
     * the enum type of the given class property
     */
    private readonly enumValueValueNames;
    /**
     * Creates a new instance
     *
     * @param imageData - The image data
     * @param propertyTextureProperty - The property texture property
     * @param classProperty - The class property
     * @param enumValueType - The `valueType` of the enum type of
     * the given class property
     * @param valueValueNames - The mapping from enum value values
     * to enum value names for the enum type of the given class
     * property
     */
    constructor(imageData: ImageData, propertyTextureProperty: any, classProperty: ClassProperty, enumValueType: string, enumValueValueNames: {
        [key: number]: string;
    });
    /** {@inheritDoc MetadataPropertyModel.getPropertyValue} */
    getPropertyValue(pixelCoordinates: [number, number]): string | string[];
    /** {@inheritDoc MetadataPropertyModel.getRawPropertyValue} */
    getRawPropertyValue(pixelCoordinates: [number, number]): number | number[];
}
//# sourceMappingURL=PropertyTextureEnumMetadataPropertyModel.d.ts.map