"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PropertyTextureMetadataPropertyModels = void 0;
const PropertyTextureNumericMetadataPropertyModel_1 = require("./PropertyTextureNumericMetadataPropertyModel");
const PropertyTextureBooleanMetadataPropertyModel_1 = require("./PropertyTextureBooleanMetadataPropertyModel");
const PropertyTextureEnumMetadataPropertyModel_1 = require("./PropertyTextureEnumMetadataPropertyModel");
/**
 * Methods to create MetadataPropertyModel instances for
 * property textures.
 */
class PropertyTextureMetadataPropertyModels {
    /**
     * Creates a new MetadataPropertyModel for the given
     * enum property texture property
     *
     * @param imageData - The image data
     * @param propertyTextureProperty - The property texture property
     * @param classProperty - The class property
     * @param enumValueType - The `valueType` of the enum type of
     * the given class property
     * @param valueValueNames - The mapping from enum value values
     * to enum value names for the enum type of the given class
     * property
     * @returns The resulting model
     */
    static createEnum(imageData, propertyTextureProperty, classProperty, enumValueType, enumValueValueNames) {
        return new PropertyTextureEnumMetadataPropertyModel_1.PropertyTextureEnumMetadataPropertyModel(imageData, propertyTextureProperty, classProperty, enumValueType, enumValueValueNames);
    }
    /**
     * Creates a new MetadataPropertyModel for the given
     * boolean property texture property
     *
     * @param imageData - The image data
     * @param propertyTextureProperty - The property texture property
     * @param classProperty - The class property
     * @returns The resulting model
     */
    static createBoolean(imageData, propertyTextureProperty, classProperty) {
        return new PropertyTextureBooleanMetadataPropertyModel_1.PropertyTextureBooleanMetadataPropertyModel(imageData, propertyTextureProperty, classProperty);
    }
    /**
     * Creates a new MetadataPropertyModel for the given
     * numeric property texture property
     *
     * @param imageData - The image data
     * @param propertyTextureProperty - The property texture property
     * @param classProperty - The class property
     * @returns The resulting model
     */
    static createNumeric(imageData, propertyTextureProperty, classProperty) {
        return new PropertyTextureNumericMetadataPropertyModel_1.PropertyTextureNumericMetadataPropertyModel(imageData, propertyTextureProperty, classProperty);
    }
}
exports.PropertyTextureMetadataPropertyModels = PropertyTextureMetadataPropertyModels;
