"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PropertyTextureNumericMetadataPropertyModel = void 0;
const _3d_tiles_tools_1 = require("3d-tiles-tools");
const _3d_tiles_tools_2 = require("3d-tiles-tools");
const ImageDataReader_1 = require("./ImageDataReader");
/**
 * Implementation of a MetadataPropertyModel for a single
 * property texture property that contains numeric values.
 *
 * @internal
 */
class PropertyTextureNumericMetadataPropertyModel {
    /**
     * Creates a new instance
     *
     * @param imageData - The image data
     * @param propertyTextureProperty - The property texture property
     * @param classProperty - The class property
     */
    constructor(imageData, propertyTextureProperty, classProperty) {
        this.imageData = imageData;
        this.propertyTextureProperty = propertyTextureProperty;
        this.classProperty = classProperty;
    }
    /** {@inheritDoc MetadataPropertyModel.getPropertyValue} */
    getPropertyValue(pixelCoordinates) {
        const propertyTextureProperty = this.propertyTextureProperty;
        const classProperty = this.classProperty;
        const offsetOverride = propertyTextureProperty.offset;
        const scaleOverride = propertyTextureProperty.scale;
        const value = this.getRawPropertyValue(pixelCoordinates);
        const processedValue = _3d_tiles_tools_1.MetadataValues.processValue(classProperty, offsetOverride, scaleOverride, value);
        return processedValue;
    }
    /** {@inheritDoc MetadataPropertyModel.getRawPropertyValue} */
    getRawPropertyValue(pixelCoordinates) {
        const propertyTextureProperty = this.propertyTextureProperty;
        const classProperty = this.classProperty;
        const channels = propertyTextureProperty.channels;
        // First, collect the actual values from the image
        // data in a buffer
        const x = pixelCoordinates[0];
        const y = pixelCoordinates[1];
        const buffer = Buffer.alloc(channels.length);
        for (let c = 0; c < channels.length; c++) {
            const channelValue = ImageDataReader_1.ImageDataReader.getChannelValue(this.imageData, x, y, c);
            buffer.writeUInt8(channelValue & 0xff, c);
        }
        const componentType = classProperty.componentType;
        // Handle array properties
        if (classProperty.array) {
            // Variable-length arrays are not supported for property
            // textures, so the `count` must be defined here
            const count = classProperty.count;
            const value = Array(count);
            for (let e = 0; e < count; e++) {
                const element = _3d_tiles_tools_2.NumericBuffers.getNumericFromBuffer(buffer, e, componentType);
                value[e] = Number(element);
            }
            return value;
        }
        // Handle (non-array) properties
        const value = _3d_tiles_tools_2.NumericBuffers.getNumericFromBuffer(buffer, 0, componentType);
        return Number(value);
    }
}
exports.PropertyTextureNumericMetadataPropertyModel = PropertyTextureNumericMetadataPropertyModel;
