import { Schema } from "3d-tiles-tools";
import { ValidationContext } from "../ValidationContext";
/**
 * A class for validations related to `propertyTexture` objects.
 *
 * This class performs the basic JSON-level validation of the
 * property texture.
 *
 * The validation of any of the underlying binary data of
 * a property texture has to start at the mesh primitive
 * that refers to the property texture, because it requires
 * knowledge about the attributes (texture coordinates)
 * that are defined in the referring mesh primitive, and
 * the glTF texture that the definition refers to.
 *
 * @internal
 */
export declare class PropertyTextureValidator {
    /**
     * Performs the validation to ensure that the given object is a
     * valid `propertyTexture` object.
     *
     * @param path - The path for the `ValidationIssue` instances
     * @param propertyTexture - The object to validate
     * @param gltf - The glTF object that contains the definitions
     * @param meshPrimitive - The mesh primitive that contains the extension
     * @param schema - The `Schema` object
     * @param context - The `ValidationContext` that any issues will be added to
     * @returns Whether the object was valid
     */
    static validatePropertyTexture(path: string, propertyTexture: any, gltf: any, schema: Schema, context: ValidationContext): boolean;
}
//# sourceMappingURL=PropertyTextureValidator.d.ts.map