import { Schema } from "3d-tiles-tools";
import { ValidationContext } from "../ValidationContext";
import { GltfData } from "./GltfData";
/**
 * A class for the validation of values that are stored
 * in property textures.
 *
 * The methods in this class assume that the structural
 * validity of the input objects has already been checked
 * by a `PropertyTextureValidator`.
 *
 * @internal
 */
export declare class PropertyTextureValuesValidator {
    /**
     * Performs the validation to ensure that the specified property
     * texture contains valid values.
     *
     * This is supposed to be called after the validity of the top-level
     * extension object, the schema, and the property texture itself have
     * been checked (the latter with
     * `PropertyTexturePropertyValidator.validatePropertyTextureProperty`).
     *
     * It assumes that they are structurally valid, and ONLY checks the
     * validity of the values in the context of the mesh primitive
     * that refers to the property texture, and the glTF texture
     * that the property texture refers to.
     *
     * @param path - The path for the `ValidationIssue` instances
     * @param propertyTextureIndex - The index that was given in the
     * `propertyTextures` array of the mesh primitive extension
     * object, and that refers to the property textures array in
     * the top-level glTF structural metadata object.
     * @param meshPrimitive - The glTF mesh primitive that contained
     * the extension object
     * @param meshIndex - The index of the mesh (only for details
     * in validation messages)
     * @param pimitiveIndex - The index of the primitive (only for details
     * in validation messages)
     * @param schema - The metadata schema
     * @param gltfStructuralMetadata - The top-level glTF structural
     * metadata object
     * @param gltfData - The glTF data
     * @param context - The `ValidationContext` that any issues will be added to
     * @returns Whether the values in the object have been valid
     */
    static validatePropertyTextureValues(path: string, propertyTextureIndex: number, meshPrimitive: any, meshIndex: number, primitiveIndex: number, schema: Schema, gltfStructuralMetadata: any, gltfData: GltfData, context: ValidationContext): Promise<boolean>;
    /**
     * Validate the values of a single property of a property texture
     *
     * @param path - The path for `ValidationIssue` instances
     * @param propertyName - The property name
     * @param propertyTextureProperty - The property texture property
     * @param schema  - The metadata schema
     * @param metadataClassName - Te class name that was given in the
     * surrounding property texture
     * @param gltfData - The glTF data
     * @param context - The `ValidationContext`
     * @returns Whether the property is valid
     */
    private static validatePropertyTexturePropertyValues;
}
//# sourceMappingURL=PropertyTextureValuesValidator.d.ts.map