import { Schema } from "3d-tiles-tools";
import { ValidationContext } from "../ValidationContext";
import { ValidatedElement } from "../ValidatedElement";
/**
 * A class for validating the definition of property textures.
 */
export declare class PropertyTexturesDefinitionValidator {
    /**
     * Validate the given definition of property textures.
     *
     * The returned object will contain two properties:
     * - `wasPresent`: Whether property textures have been given
     * - `validatedElement`: The validated `PropertyTexture[]` object
     *
     * When no property textures are given, then it will just return
     * `{false, undefined}`.
     *
     * If the given `schemaState` indicates that no schema was present,
     * or the property textures have not been valid according to the
     * schema, then an error will be added to the given context,
     * and `{true, undefined}` is returned.
     *
     * The method will return `{true, propertyTextures}` only if the
     * given property textures have been valid.
     *
     * @param path - The path for `ValidationIssue` instances
     * @param name - The name of the object containing the definition
     * (for example, 'metadata extension object')
     * @param propertyTextures - The actual property textures
     * @param gltf - The containing glTF object
     * @param schemaState - The state of the schema validation
     * @param context - The `ValidationContext`
     * @returns Information about the validity of the definition
     */
    static validatePropertyTexturesDefinition(path: string, name: string, propertyTextures: any[] | undefined, gltf: any, schemaState: ValidatedElement<Schema>, context: ValidationContext): ValidatedElement<any[]>;
}
//# sourceMappingURL=PropertyTexturesDefinitionValidator.d.ts.map