import { ValidationContext } from "../ValidationContext";
/**
 * Methods for validating glTF `sampler` objects in the context
 * of the glTF metadata extension validation.
 */
export declare class SamplerValidator {
    /**
     * Make sure that the given sampler has `minFilter` and `maxFilter`
     * properties that are either `undefined` or `NEAREST`.
     *
     * @param path - The path for the `ValidationIssue` instances
     * @param sampler - The sampler object
     * @param context - The `ValidationContext` that any issues will be added to
     * @returns Whether the object was valid
     */
    static validateSamplerNearest(path: string, sampler: any, context: ValidationContext): boolean;
    /**
     * Make sure that the given sampler has `minFilter` and `maxFilter`
     * properties that are either `undefined`, `NEAREST`, or `LINEAR`.
     *
     * @param path - The path for the `ValidationIssue` instances
     * @param sampler - The sampler object
     * @param context - The `ValidationContext` that any issues will be added to
     * @returns Whether the object was valid
     */
    static validateSamplerNearestOrLinear(path: string, sampler: any, context: ValidationContext): boolean;
    /**
     * Make sure that the given sampler has `minFilter` and `maxFilter`
     * properties that are one of the given allowed values, creating
     * a validation error in the given context if this is not the
     * case.
     *
     * @param path - The path for the `ValidationIssue` instances
     * @param sampler - The sampler object
     * @param allowedValues - The allowed values
     * @param allowedValuesString - A string that will describe the allowed
     * values in the validation issues
     * @param context - The `ValidationContext` that any issues will be added to
     * @returns Whether the object was valid
     */
    private static validateSampler;
}
//# sourceMappingURL=SamplerValidator.d.ts.map