"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BinaryPropertyTableDefaultMetadataPropertyModel = void 0;
const _3d_tiles_tools_1 = require("3d-tiles-tools");
const _3d_tiles_tools_2 = require("3d-tiles-tools");
/**
 * Implementation of a `MetadataPropertyModel` for properties
 * that are stored in binary property tables, and that are not
 * ENUM properties.
 *
 * @internal
 */
class BinaryPropertyTableDefaultMetadataPropertyModel {
    /**
     * Creates a new instance
     *
     * @param binaryPropertyTable - The binary property table
     * @param propertyName - The property name
     * @param propertyTableProperty - The property table property
     * @param classProperty - The class property
     */
    constructor(binaryPropertyTable, propertyName, propertyTableProperty, classProperty) {
        this.propertyTableProperty = propertyTableProperty;
        this.classProperty = classProperty;
        this.propertyModel = _3d_tiles_tools_2.BinaryPropertyModels.createPropertyModel(binaryPropertyTable, propertyName);
    }
    /** {@inheritDoc MetadataPropertyModel.getPropertyValue} */
    getPropertyValue(key) {
        const propertyAttributeProperty = this.propertyTableProperty;
        const classProperty = this.classProperty;
        const offsetOverride = propertyAttributeProperty.offset;
        const scaleOverride = propertyAttributeProperty.scale;
        const value = this.getRawPropertyValue(key);
        const processedValue = _3d_tiles_tools_1.MetadataValues.processValue(classProperty, offsetOverride, scaleOverride, value);
        return processedValue;
    }
    /** {@inheritDoc MetadataPropertyModel.getRawPropertyValue} */
    getRawPropertyValue(key) {
        return this.propertyModel.getPropertyValue(key);
    }
}
exports.BinaryPropertyTableDefaultMetadataPropertyModel = BinaryPropertyTableDefaultMetadataPropertyModel;
