"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BinaryPropertyTableEnumMetadataPropertyModel = void 0;
const _3d_tiles_tools_1 = require("3d-tiles-tools");
const _3d_tiles_tools_2 = require("3d-tiles-tools");
/**
 * Implementation of a `MetadataPropertyModel` for ENUM properties
 * in a binary property table
 *
 * @internal
 */
class BinaryPropertyTableEnumMetadataPropertyModel {
    /**
     * Creates a new instance
     *
     * @param binaryPropertyTable - The binary property table
     * @param propertyName - The property name
     * @param propertyTableProperty - The property table property
     * @param classProperty - The class property
     * @param enumValueValueNames - The mapping from enum value values
     * to enum value names for the enum type of the given class
     * property
     */
    constructor(binaryPropertyTable, propertyName, classProperty, enumValueValueNames) {
        this.classProperty = classProperty;
        this.enumValueValueNames = enumValueValueNames;
        this.propertyModel = _3d_tiles_tools_2.BinaryPropertyModels.createPropertyModel(binaryPropertyTable, propertyName);
    }
    /** {@inheritDoc MetadataPropertyModel.getPropertyValue} */
    getPropertyValue(key) {
        const classProperty = this.classProperty;
        const value = this.getRawPropertyValue(key);
        const processedValue = _3d_tiles_tools_1.MetadataValues.processNumericEnumValue(classProperty, this.enumValueValueNames, value);
        return processedValue;
    }
    /** {@inheritDoc MetadataPropertyModel.getRawPropertyValue} */
    getRawPropertyValue(key) {
        return this.propertyModel.getPropertyValue(key);
    }
}
exports.BinaryPropertyTableEnumMetadataPropertyModel = BinaryPropertyTableEnumMetadataPropertyModel;
