import { BinaryPropertyTable } from "3d-tiles-tools";
import { ValidationContext } from "../ValidationContext";
/**
 * A class for the validation of values that are stored
 * in binary property tables.
 *
 * The methods in this class assume that the structural
 * validity of the input objects has already been checked
 * by a `PropertyTableValidator` and a
 * `BinaryPropertyTableValidator`.
 *
 * @internal
 */
export declare class BinaryPropertyTableValuesValidator {
    /**
     * Performs the validation to ensure that the given
     * `BinaryPropertyTable` contains valid values.
     *
     * @param path - The path for the `ValidationIssue` instances
     * @param binaryPropertyTable - The object to validate
     * @param context - The `ValidationContext` that any issues will be added to
     * @returns Whether the values in the object have been valid
     */
    static validateBinaryPropertyTableValues(path: string, binaryPropertyTable: BinaryPropertyTable, context: ValidationContext): boolean;
    /**
     * Validate the values of a single property of a `BinaryPropertyTable`
     *
     * @param path - The path of the `PropertyTablePropery`, for
     * `ValidationIssue` instances
     * @param propertyName - The property name
     * @param classProperty - The `ClassProperty`
     * @param binaryPropertyTable - The `BinaryPropertyTable`
     * @param context - The `ValidationContext`
     * @returns Whether the property is valid
     */
    private static validateBinaryPropertyTablePropertyValues;
}
//# sourceMappingURL=BinaryPropertyTableValuesValidator.d.ts.map