import { ClassProperty } from "3d-tiles-tools";
import { ValidationContext } from "../ValidationContext";
/**
 * Methods for common validation tasks of metadata properties.
 *
 * The methods in this class assume that the class property definitions
 * have already been validated with the `ClassPropertyValidator`.
 *
 * @internal
 */
export declare class MetadataPropertyValidator {
    /**
     * Validates the given property object against the given class property
     * definition.
     *
     * The given object may be any object that defines the common elements
     * of a metadata property, namely `offset/scale/max/min`.
     *
     * This method will ensure that these elements are NOT given if the
     * given class property indicates a variable-length array. If they
     * are given, it will ensure that their structure matches the
     * structure that is defined by the class property definiton.
     *
     * @param path - The path for the `ValidationIssue` instances
     * @param property - The object to validate
     * @param propertyName - The name of the property
     * @param classProperty - The `ClassProperty` definition from the schema
     * @param context - The `ValidationContext` that any issues will be added to
     * @returns Whether the object was valid
     */
    static validateOffsetScaleMaxMin(path: string, property: {
        offset?: any;
        scale?: any;
        max?: any;
        min?: any;
    }, propertyName: string, classProperty: ClassProperty, context: ValidationContext): boolean;
}
//# sourceMappingURL=MetadataPropertyValidator.d.ts.map