import { ClassProperty } from "3d-tiles-tools";
/**
 * Utility methods related to the messages that are part of
 * validation issues in the metadata validation.
 */
export declare class MetadataValuesValidationMessages {
    /**
     * Creates a message that describes how a metadata value was computed.
     *
     * The intention is to insert this as `The value is ${valueMessagePart}`
     * in a message that explains how the `value` was computed from the
     * raw value, normalization, offset and scale.
     *
     * @param rawValue - The raw value (e.g. from the `PropertyModel`),
     * without normalization, offset, or scale
     * @param classProperty - The class property
     * @param property - The property, which may contain `scale` or
     * `offset` properties that override the respective value from
     * the class property
     * @param value - The final value
     * @returns The message part
     */
    static createValueMessagePart(rawValue: any, classProperty: ClassProperty, property: {
        scale?: any;
        offset?: any;
    }, value: any): string;
}
//# sourceMappingURL=MetadataValueValidationMessages.d.ts.map