import { PropertyTable } from "3d-tiles-tools";
import { Schema } from "3d-tiles-tools";
import { ValidationContext } from "../ValidationContext";
import { ValidatedElement } from "../ValidatedElement";
/**
 * A class for validating the definition of property tables.
 */
export declare class PropertyTablesDefinitionValidator {
    /**
     * Validate the given definition of property tables.
     *
     * The returned object will contain two properties:
     * - `wasPresent`: Whether property tables have been given
     * - `validatedElement`: The validated `PropertyTables[]` object
     *
     * When no property tables are given, then it will just return
     * `{false, undefined}`.
     *
     * If the given `schemaState` indicates that no schema was present,
     * or the property tables have not been valid according to the
     * schema, then an error will be added to the given context,
     * and `{true, undefined}` is returned.
     *
     * The method will return `{true, propertyTables}` only if the
     * given property tables have been valid.
     *
     * @param path - The path for `ValidationIssue` instances
     * @param name - The name of the object containing the definition
     * (for example, 'subtree')
     * @param propertyTables - The actual property tables
     * @param numBufferViews - The number of buffer views in the
     * containing object
     * @param schemaState - The state of the schema validation
     * @param context - The `ValidationContext`
     * @returns Information about the validity of the definition
     */
    static validatePropertyTablesDefinition(path: string, name: string, propertyTables: PropertyTable[] | undefined, numBufferViews: number, schemaState: ValidatedElement<Schema>, context: ValidationContext): ValidatedElement<PropertyTable[]>;
}
//# sourceMappingURL=PropertyTablesDefinitionValidator.d.ts.map